<h1>
  <img src="https://github.com/kdqed/zaturn/raw/main/zaturn/studio/static/logo.png" width="24" height="24">
  <span>Zaturn: Your Co-Pilot For Data Analytics & Business Insights</span>
</h1>

<a href="https://discord.gg/K8mECeVzpQ">
  <img src="https://zaturn.pro/assets/discord-full.png" height="20" width="133" alt="Discord Logo">
</a>

## Just Chat With Your Data! No SQL, No Python.

Zaturn provides tools that enable AI models to run SQL, so you don't have to. It can be used as an MCP or as a web interface similar to Jupyter Notebook.

## Zaturn in Action

https://github.com/user-attachments/assets/d42dc433-e5ec-4b3e-bef0-5cfc097396ab

## Features:

### Multiple Data Sources 

Zaturn can currently connect to the following data sources: 
- SQL Databases: PostgreSQL, SQLite, DuckDB, MySQL, ClickHouse, SQL Server
- Files: CSV, Parquet

Connectors for more data sources are being added.

### Visualizations

In addition to providing tabular and textual summaries, Zaturn can also generate the following image visualizations

- Scatter and Line Plots
- Histograms
- Strip and Box Plots
- Bar Plots

More visualization capabilities are being added.


## Installation & Setup

See [https://zaturn.pro/docs/install](https://zaturn.pro/docs/install)


## Roadmap

- Support for more data source types
- More data visualizations
- Predictive analysis and forecasting, e.g.:
```
Based on the revenue of the last 3 months, forecast next month's revenue.
```
- Generate Presentations & PDFs
```
Manager: 
  I need a presentation to show the boss. Can you do it by EOD?
Analyst: 
  EOD?! Are you still in the 2010s? 
  I can get it done right now. Actually, you can do it right now.
  You know what? The boss can do it right now.
```

## Help And Feedback

[Raise an issue](https://github.com/kdqed/zaturn/issues) or [join the Discord](https://discord.gg/K8mECeVzpQ).


## Support The Project

If you find Zaturn useful, please support this project by:
- Starring the Project
- Spreading the word

Your support will enable me to dedicate more of my time to Zaturn.

## Example Dataset Credits

The [pokemon dataset compiled by Sarah Taha and PokéAPI](https://www.kaggle.com/datasets/sarahtaha/1025-pokemon) has been included under the [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/) license for demonstration purposes.

## Featured on glama.ai

<a href="https://glama.ai/mcp/servers/@kdqed/zaturn">
  <img width="380" height="200" src="https://glama.ai/mcp/servers/@kdqed/zaturn/badge" alt="Zaturn MCP server" />
</a>


## Star History

[![Star History Chart](https://api.star-history.com/svg?repos=kdqed/zaturn&type=Date)](https://www.star-history.com/#kdqed/zaturn&Date)
